pub type InitialCustomStateEvent = InitialStateEvent<CustomStateEventContent>;Expand description
An rs.matrix-sdk.custom-state.test event for creating a room.
Aliased Type
pub struct InitialCustomStateEvent {
pub content: CustomStateEventContent,
pub state_key: String,
}Fields
content: CustomStateEventContentData specific to the event type.
state_key: StringA unique key which defines the overwriting semantics for this piece of room state.
This must be a string type, and is often an empty string.
A state event is keyed by its (type, state_key) tuple. Sending another state event with
the same tuple replaces the previous one.
Defaults to the empty string.