OriginalSyncCustomStateEvent

Type Alias OriginalSyncCustomStateEvent 

pub type OriginalSyncCustomStateEvent = OriginalSyncStateEvent<CustomStateEventContent>;
An rs.matrix-sdk.custom-state.test event from a sync_events response.

Aliased Type

pub struct OriginalSyncCustomStateEvent {
    pub content: CustomStateEventContent,
    pub event_id: OwnedEventId,
    pub sender: OwnedUserId,
    pub origin_server_ts: MilliSecondsSinceUnixEpoch,
    pub state_key: String,
    pub unsigned: StateUnsigned<CustomStateEventContent>,
}

Fields

content: CustomStateEventContent

Data specific to the event type.

event_id: OwnedEventId

The globally unique identifier for the event.

sender: OwnedUserId

The fully-qualified ID of the user who sent this event.

origin_server_ts: MilliSecondsSinceUnixEpoch

Timestamp on the originating homeserver when this event was sent.

state_key: String

A unique key which defines the overwriting semantics for this piece of room state.

This must be a string type, and is often an empty string.

A state event is keyed by its (type, state_key) tuple. Sending another state event with the same tuple replaces the previous one.

unsigned: StateUnsigned<CustomStateEventContent>

Additional key-value pairs not signed by the homeserver.