pub type StrippedCustomStateEvent = StrippedStateEvent<PossiblyRedactedCustomStateEventContent>;Expand description
An rs.matrix-sdk.custom-state.test event from an invited room preview.
Aliased Type
pub struct StrippedCustomStateEvent {
pub content: CustomStateEventContent,
pub sender: OwnedUserId,
pub state_key: String,
}Fields
content: CustomStateEventContentData specific to the event type.
sender: OwnedUserIdThe fully-qualified ID of the user who sent this event.
state_key: StringA unique key which defines the overwriting semantics for this piece of room state.
This must be a string type, and is often an empty string.
A state event is keyed by its (type, state_key) tuple. Sending another state event with
the same tuple replaces the previous one.